==> lxqt-panel_1.1.0.orig.tar.xz: lxqt-panel-1.1.0/plugin-directorymenu/translations/directorymenu_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../directorymenu.cpp" line="126"/>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <location filename="../directorymenu.cpp" line="130"/>
        <source>Open in terminal</source>
        <translation>端末で開く</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>ディレクトリメニューの設定</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>外観</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>ベースディレクトリ:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>ベースディレクトリの名前</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>アイコン:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="66"/>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="86"/>
        <source>Button style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="103"/>
        <source>Terminal</source>
        <translation>端末</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="96"/>
        <location filename="../directorymenuconfiguration.cpp" line="131"/>
        <source>Choose Default Terminal</source>
        <translation>既定の端末を選択</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="54"/>
        <source>Only icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="55"/>
        <source>Only text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="56"/>
        <source>Icon and text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="115"/>
        <source>Choose Base Directory</source>
        <translation>ベースディレクトリを選ぶ</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="164"/>
        <source>Choose Icon</source>
        <translation>アイコンを選ぶ</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="164"/>
        <source>Icons (*.png *.xpm *.jpg *.svg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="188"/>
        <source>Choose Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="189"/>
        <source>Label:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="173"/>
        <source>Directory Menu</source>
        <translation>ディレクトリメニュー</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="173"/>
        <source>An error occurred while loading the icon.</source>
        <translation>アイコンのロード中にエラーが発生しました。</translation>
    </message>
</context>
</TS>

==> lxqt-panel_1.2.1.orig.tar.xz: lxqt-panel-1.2.1/plugin-directorymenu/translations/directorymenu_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../directorymenu.cpp" line="126"/>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <location filename="../directorymenu.cpp" line="130"/>
        <source>Open in terminal</source>
        <translation>端末で開く</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>ディレクトリメニューの設定</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>外観</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>ベースディレクトリ:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>ベースディレクトリの名前</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>アイコン:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="66"/>
        <source>Label</source>
        <translation>ラベル</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="86"/>
        <source>Button style</source>
        <translation>ボタンのスタイル</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="103"/>
        <source>Terminal</source>
        <translation>端末</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="96"/>
        <location filename="../directorymenuconfiguration.cpp" line="131"/>
        <source>Choose Default Terminal</source>
        <translation>既定の端末を選択</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="54"/>
        <source>Only icon</source>
        <translation>アイコンのみ</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="55"/>
        <source>Only text</source>
        <translation>テキストのみ</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="56"/>
        <source>Icon and text</source>
        <translation>アイコンとテキスト</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="115"/>
        <source>Choose Base Directory</source>
        <translation>ベースディレクトリを選ぶ</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="164"/>
        <source>Choose Icon</source>
        <translation>アイコンを選ぶ</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="164"/>
        <source>Icons (*.png *.xpm *.jpg *.svg)</source>
        <translation>アイコン (*.png *.xpm *.jpg *.svg)</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="188"/>
        <source>Choose Label</source>
        <translation>ラベルの選択</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="189"/>
        <source>Label:</source>
        <translation>ラベル:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="173"/>
        <source>Directory Menu</source>
        <translation>ディレクトリメニュー</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="173"/>
        <source>An error occurred while loading the icon.</source>
        <translation>アイコンのロード中にエラーが発生しました。</translation>
    </message>
</context>
</TS>
